@@ -90,7 +90,7 @@ void FilterEvolution_v3::processDirectory(const QString &path)
         if (filterInfo()->shouldTerminate()) {
             break;
         }
-        if (!(*filename == QLatin1String(".") || *filename == QLatin1String(".."))) {
+        if (!(*filename == QLatin1Char('.') || *filename == QLatin1String(".."))) {
             filterInfo()->setCurrent(0);
             importDirContents(dir.filePath(*filename));
             filterInfo()->setOverall((d->mTotalDir > 0) ? (int)((float)d->mImportDirDone / d->mTotalDir * 100) : 0);
@@ -179,18 +179,18 @@ void FilterEvolution_v3::importFiles(const QString &dirName)
             if (!generatedPath) {
                 _path = i18nc("define folder name where we import evolution mails", "Evolution-Import");
                 QString _tmp = dir.filePath(*mailFile);
-                _tmp = _tmp.remove(mailDir(), Qt::CaseSensitive);
+                _tmp.remove(mailDir(), Qt::CaseSensitive);
                 QStringList subFList = _tmp.split(QLatin1Char('/'), QString::SkipEmptyParts);
                 QStringList::ConstIterator end(subFList.end());
                 for (QStringList::ConstIterator it = subFList.constBegin(); it != end; ++it) {
                     QString _cat = *it;
                     if (!(_cat == *mailFile)) {
                         if (_cat.startsWith(QLatin1Char('.'))) {
-                            _cat = _cat.remove(0, 1);
+                            _cat.remove(0, 1);
                         }
                         //Evolution store inbox as "."
                         if (_cat.startsWith(QLatin1Char('.'))) {
-                            _cat = _cat.replace(0, 1, QStringLiteral("Inbox/"));
+                            _cat.replace(0, 1, QStringLiteral("Inbox/"));
                         }
 
                         _path += QLatin1Char('/') + _cat;
@@ -219,7 +219,7 @@ void FilterEvolution_v3::importFiles(const QString &dirName)
 MailImporter::MessageStatus FilterEvolution_v3::statusFromFile(const QString &filename)
 {
     MailImporter::MessageStatus status;
-    const int statusIndex = filename.indexOf(QStringLiteral(":2,"));
+    const int statusIndex = filename.indexOf(QLatin1String(":2,"));
     if (statusIndex != -1) {
         const QString statusStr = filename.right(filename.length() - statusIndex - 3);
         if (statusStr.contains(QLatin1Char('S'))) {
